%-------------------------------------------------------------------------%
%         This software is licensed by Creative Commons BY-NC-SA:         %
%      http://creativecommons.org/licenses/by-nc-sa/3.0/it/legalcode      %
%-------------------------------------------------------------------------%
%
% File: ProgIntegr3D(t,y,par,options)
%
% Goal: function used to declare the model 
%
% Inputs: t:       integration time
%         y:       initial condition for integration
%         par:     model parameters
%         options: option used with an integration routine
%	 
% Outputs: dy: model equations to be integrated
%
% Remark: used in an integration routine
%
%-------------------------------------------------------------------------%
function dy=ProgIntegr3D(t,y,par,options)
dy=zeros(3,1);
dy(1)= par(1)*(1-y(1)/par(2))*y(1)-par(3)*y(2)*y(1)-par(4)*y(3)*y(1);
dy(2)= par(5)*(1-y(2)/par(6))*y(2)-par(7)*y(2)*y(1)-par(8)*y(2)*y(3);
dy(3)= par(9)*(1-y(3)/par(10))*y(3)-par(11)*y(1)*y(3)-par(12)*y(2)*y(3);
return
















